pub const fn samples_per_2_5ms(sample_rate: SampleRate) -> usizeExpand description
Number of samples per channel in a 2.5 ms frame at the given sample_rate.
libopus requires PLC/FEC and DRED frame sizes to be multiples of this value.
pub const fn samples_per_2_5ms(sample_rate: SampleRate) -> usizeNumber of samples per channel in a 2.5 ms frame at the given sample_rate.
libopus requires PLC/FEC and DRED frame sizes to be multiples of this value.