packet_parse_into

Function packet_parse_into 

pub fn packet_parse_into<'packet>(
    packet: &'packet [u8],
    frames: &mut [&'packet [u8]],
) -> Result<(u8, usize, usize)>
Parse a packet into caller-provided frame storage.

Returns (toc, payload_offset, frame_count). The first frame_count entries in frames are replaced with slices that borrow from packet.

Errors

Returns Error::BufferTooSmall if frames cannot hold every parsed frame, or another error if the packet cannot be parsed.