packet_parse

Function packet_parse 

pub fn packet_parse(packet: &[u8]) -> Result<(u8, usize, Vec<&[u8]>)>
Parse packet into frame slices. Returns (toc, payload_offset, frames).

Returned frame slices borrow from packet and are valid as long as packet lives. Use packet_parse_into to supply reusable storage and avoid allocating the returned vector.

Errors

Returns an error if the packet cannot be parsed.